@@ -103,6 +103,20 @@ func (g *Generator) syncStorage(cr *imageregistryv1.Config) error {
 			return err
 		}
 	}
+
+	// XXX BZ 1722878
+	// This is a workaround for a bug that affected OCP 4.2 and earlier. We
+	// may have multiple storage engines set on Status, that is not a valid
+	// situation. Here we check if this is the case and if yes we fix it by
+	// copying what we have on the Spec into the Status.
+	_, err = storage.NewDriver(
+		&cr.Status.Storage, g.kubeconfig, g.listers,
+	)
+	if _, ok := err.(*storage.MultiStoragesError); ok {
+		specCopy := cr.Spec.Storage.DeepCopy()
+		cr.Status.Storage = *specCopy
+	}
+
 	return nil
 }
 
